if select(6, GetAddOnInfo("PitBull_" .. (debugstack():match("[i%.][t%.][B%.]ull\\Modules\\(.-)\\") or debugstack():match("[i%.][t%.][B%.]ull\\(.-)\\") or ""))) ~= "MISSING" then return end

local VERSION = tonumber(("$Revision: 39962 $"):match("%d+"))

local PitBull = PitBull
local PitBull_LeaderIcon = PitBull:NewModule("LeaderIcon", "AceEvent-2.0")
local self = PitBull_LeaderIcon
if PitBull.revision < VERSION then
	PitBull.version = "r" .. VERSION
	PitBull.revision = VERSION
	PitBull.date = ("$Date: 2007-06-14 21:09:38 -0400 (Thu, 14 Jun 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end
self.desc = "Show an icon on the unit frame when the unit is the group leader."

local L = PitBull:L("PitBull-LeaderIcon")

local new, del, newHash = PitBull.new, PitBull.del, PitBull.newHash
local newFrame, delFrame = PitBull.newFrame, PitBull.delFrame

PitBull_LeaderIcon:RegisterPitBullChildFrames('leaderIcon')

function PitBull_LeaderIcon:OnInitialize()
	self.db = PitBull:AcquireDBNamespace("LeaderIcon")
	PitBull:RegisterDefaults("LeaderIcon", "profile", {
		['*'] = {
			disable = false,
		},
	})
end

function PitBull_LeaderIcon:OnEnable()
	self:RegisterEvent("PARTY_LEADER_CHANGED")
	self:RegisterEvent("PARTY_MEMBERS_CHANGED", "PARTY_LEADER_CHANGED")
	self:RegisterEvent("RAID_ROSTER_UPDATE", "PARTY_LEADER_CHANGED")
end

function PitBull_LeaderIcon:Update(unit, frame)
	if frame.group ~= "player" and frame.group ~= "party" and frame.group ~= "raid" then
		return
	end
	local has = true
	if unit == "player" then
		if not IsPartyLeader() then
			has = false
		end
	else
		local raid = unit:match("^raid(%d%d?)$")
		if raid then
			local _, rank = GetRaidRosterInfo(tonumber(raid))
			if rank ~= 2 then
				has = false
			end
		else
			local party = unit:match("^party(%d)$")
			if party then
				if GetPartyLeaderIndex() ~= tonumber(party) then
					has = false
				end
			else
				has = false
			end
		end
	end
	if PitBull.configMode and not UnitExists(unit) then
		has = true
	end
	if self.db.profile[frame.group].disable then
		has = false
	end
	
	if has then
		if not frame.leaderIcon then
			local leaderIcon = newFrame("Texture", frame.overlay, "ARTWORK")
			frame.leaderIcon = leaderIcon
			leaderIcon:SetTexture("Interface\\GroupFrame\\UI-Group-LeaderIcon")
			leaderIcon:Hide()
			PitBull:UpdateLayout(frame)
		end
	else
		if frame.leaderIcon then
			frame.leaderIcon = delFrame(frame.leaderIcon)
			
			PitBull:UpdateLayout(frame)
		end
	end
end

local function UpdateStuff(self)
	for unit, frame in PitBull:IterateNonWackyUnitFrames() do
		self:Update(unit, frame)
	end
end

function PitBull_LeaderIcon:PARTY_LEADER_CHANGED()
	self:ScheduleEvent("PitBull_LeaderIcon-UpdateStuff", UpdateStuff, 0, self)
end

function PitBull_LeaderIcon:OnUpdateFrame(unit, frame)
	self:Update(unit, frame)
end

function PitBull_LeaderIcon:OnClearUnitFrame(unit, frame)
	if frame.leaderIcon then
		frame.leaderIcon = delFrame(frame.leaderIcon)
	end
end

function PitBull_LeaderIcon:OnUnknownLayout(unit, frame)
	frame.leaderIcon:SetPoint("CENTER", frame, "TOPLEFT", 0, 0)
	frame.leaderIcon:SetWidth(12)
	frame.leaderIcon:SetHeight(12)
end

local function getEnable(group)
	return not PitBull_LeaderIcon.db.profile[group].disable
end
local function setEnable(group, value)
	PitBull_LeaderIcon.db.profile[group].disable = not value
	
	for unit, frame in PitBull:IterateUnitFramesByGroup(group) do
		PitBull_LeaderIcon:Update(unit, frame)
	end
end
PitBull_LeaderIcon:RegisterPitBullOptionsMethod(function(group)
	if group == "player" or group == "party" or group == "raid" then
		return {
			type = "toggle",
			name = L["Enable leader icon"],
			desc = L["Enables the leader icon, indicating who is the current group or raid leader."],
			get = getEnable,
			set = setEnable,
			passValue = group,
		}
	end
end)
